# Find JCMWAVE v0.0.4
A minimal package that finds the third party support library of jcmwave by looking at the `JCMROOT` environment variable. 
Install by:

```bash
pip install find_jcmwave
```

```python
import find_jcmwave as jcmwave
```

and never worry about linking your jcmwave python library anymore